==> googsystray-1.2.0.tar.gz: googsystray-1.2.0/pkg/win/post_py2exe.py <==

import os, sys, shutil
from googsystray import VERSION_STRING

# too lazy to dick with this -- hardcoding time
def find_path(path_str):
    return "C:\\opt\\" + path_str
    

def include(src, dest, exclude=[]):
    if not os.path.exists(dest):
        print "copying %s..." % dest
        
        # ensure base exists
        base = os.path.split(dest)[0]
        if not os.path.exists(base):
            os.makedirs(base)
        
        print shutil.copytree(src, dest)

def prune(path):
    if os.path.exists(path):
        print "pruning %s..." % path
        if os.path.isdir(path):
            shutil.rmtree(path)
        else:
            os.remove(path)

        
include(find_path("GTK/lib/gtk-2.0/2.10.0/engines"), "dist/googsystray-" + VERSION_STRING + ".win/lib/gtk-2.0/2.10.0/engines")
include(find_path("GTK/lib/gtk-2.0/2.10.0/loaders"), "dist/googsystray-" + VERSION_STRING + ".win/lib/gtk-2.0/2.10.0/loaders")
include(find_path("GTK/etc"), "dist/googsystray-" + VERSION_STRING + ".win/etc")
# include(find_path("GTK/share/gettext"), "dist/googsystray-" + VERSION_STRING + ".win/share/gettext")
include(find_path("GTK/share/glib-2.0"), "dist/googsystray-" + VERSION_STRING + ".win/share/glib-2.0")
include(find_path("GTK/share/gtk-2.0"), "dist/googsystray-" + VERSION_STRING + ".win/share/gtk-2.0")
#include(find_path("GTK/share/locale/en@quot"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en@quot")
#include(find_path("GTK/share/locale/en@boldquot"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en@boldquot")
#include(find_path("GTK/share/locale/en_CA"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en_CA")
#include(find_path("GTK/share/locale/en_GB"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en_GB")
for i in supported_translations:
    include(find_path("GTK/share/locale/"+i), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/"+i)
include(find_path("GTK/share/themes"), "dist/googsystray-" + VERSION_STRING + ".win/share/themes")
print shutil.copy("CHANGELOG", "dist/googsystray-" + VERSION_STRING + ".win/CHANGELOG.txt")

==> googsystray-1.3.1.tar.gz: googsystray-1.3.1/pkg/win/post_py2exe.py <==

import os, sys, shutil
from googsystray import VERSION_STRING

# too lazy to dick with this -- hardcoding time
def find_path(path_str):
    return "C:\\opt\\" + path_str
    

def include(src, dest, exclude=[]):
    if not os.path.exists(dest):
        print "copying %s..." % dest
        
        # ensure base exists
        base = os.path.split(dest)[0]
        if not os.path.exists(base):
            os.makedirs(base)
        
        print shutil.copytree(src, dest)

def prune(path):
    if os.path.exists(path):
        print "pruning %s..." % path
        if os.path.isdir(path):
            shutil.rmtree(path)
        else:
            os.remove(path)

include(find_path("Microsoft.VC90.CRT"), "dist/googsystray-" + VERSION_STRING + ".win/Microsoft.VC90.CRT")
include(find_path("GTK/lib/gtk-2.0/2.10.0/engines"), "dist/googsystray-" + VERSION_STRING + ".win/lib/gtk-2.0/2.10.0/engines")
#include(find_path("GTK/lib/gtk-2.0/2.10.0/loaders"), "dist/googsystray-" + VERSION_STRING + ".win/lib/gtk-2.0/2.10.0/loaders")
include(find_path("GTK/etc"), "dist/googsystray-" + VERSION_STRING + ".win/etc")
# include(find_path("GTK/share/gettext"), "dist/googsystray-" + VERSION_STRING + ".win/share/gettext")
include(find_path("GTK/share/glib-2.0"), "dist/googsystray-" + VERSION_STRING + ".win/share/glib-2.0")
include(find_path("GTK/share/gtk-2.0"), "dist/googsystray-" + VERSION_STRING + ".win/share/gtk-2.0")
#include(find_path("GTK/share/locale/en@quot"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en@quot")
#include(find_path("GTK/share/locale/en@boldquot"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en@boldquot")
#include(find_path("GTK/share/locale/en_CA"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en_CA")
#include(find_path("GTK/share/locale/en_GB"), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/en_GB")
for i in supported_translations:
    include(find_path("GTK/share/locale/"+i), "dist/googsystray-" + VERSION_STRING + ".win/share/locale/"+i)
include(find_path("GTK/share/themes"), "dist/googsystray-" + VERSION_STRING + ".win/share/themes")
print shutil.copy("CHANGELOG", "dist/googsystray-" + VERSION_STRING + ".win/CHANGELOG.txt")
